@@ -1,13 +1,7 @@
-package MooseX::MethodAttributes;
-# git description: v0.27-5-g5bfa6f6
+package MooseX::MethodAttributes; # git description: v0.30-2-gc4a23df
+# ABSTRACT: Code attribute introspection
 
-BEGIN {
-  $MooseX::MethodAttributes::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $MooseX::MethodAttributes::VERSION = '0.28';
-}
-# ABSTRACT: code attribute introspection
+our $VERSION = '0.31';
 
 use Moose ();
 use Moose::Exporter;
@@ -15,7 +9,31 @@ use Moose::Util::MetaRole;
 use Moose::Util qw/find_meta does_role/;
 # Ensure trait is registered
 use MooseX::MethodAttributes::Role::Meta::Role ();
+use namespace::autoclean;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod     package MyClass;
+#pod
+#pod     use Moose;
+#pod     use MooseX::MethodAttributes;
+#pod
+#pod     sub foo : Bar Baz('corge') { ... }
+#pod
+#pod     my $attrs = MyClass->meta->get_method('foo')->attributes; # ["Bar", "Baz('corge')"]
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This module allows code attributes of methods to be introspected using Moose
+#pod meta method objects.
+#pod
+#pod =begin Pod::Coverage
+#pod
+#pod init_meta
+#pod
+#pod =end Pod::Coverage
+#pod
+#pod =cut
 
 Moose::Exporter->setup_import_methods(
     also => 'Moose',
@@ -59,11 +77,15 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-MooseX::MethodAttributes - code attribute introspection
+MooseX::MethodAttributes - Code attribute introspection
+
+=head1 VERSION
+
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -83,6 +105,17 @@ meta method objects.
 
 =for Pod::Coverage init_meta
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-MethodAttributes>
+(or L<bug-MooseX-MethodAttributes@rt.cpan.org|mailto:bug-MooseX-MethodAttributes@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#moose.
+
 =head1 AUTHORS
 
 =over 4
@@ -97,9 +130,37 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTORS
 
-This software is copyright (c) 2012 by Florian Ragwitz.
+=for stopwords Karen Etheridge Dave Rolsky Marcus Ramberg Peter E Karman David Steinbrunner
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Marcus Ramberg <marcus@nordaaker.com>
+
+=item *
+
+Peter E Karman <pek@dewpoint.msi.umn.edu>
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
