@@ -1,16 +1,17 @@
 package MooseX::MethodAttributes::Role::Meta::Method;
-BEGIN {
-  $MooseX::MethodAttributes::Role::Meta::Method::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $MooseX::MethodAttributes::Role::Meta::Method::VERSION = '0.28';
-}
 # ABSTRACT: metamethod role allowing code attribute introspection
 
+our $VERSION = '0.31';
+
 use Moose::Role;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
+#pod =attr attributes
+#pod
+#pod Gets the list of code attributes of the method represented by this meta method.
+#pod
+#pod =cut
 
 has attributes => (
     is      => 'ro',
@@ -18,6 +19,12 @@ has attributes => (
     builder => '_build_attributes',
 );
 
+#pod =method _build_attributes
+#pod
+#pod Builds the value of the C<attributes> attribute based on the attributes
+#pod captured in the associated meta class.
+#pod
+#pod =cut
 
 sub _build_attributes {
     my ($self) = @_;
@@ -35,12 +42,16 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method - metamethod role allowing code attribute introspection
 
+=head1 VERSION
+
+version 0.31
+
 =head1 ATTRIBUTES
 
 =head2 attributes
@@ -54,6 +65,17 @@ Gets the list of code attributes of the method represented by this meta method.
 Builds the value of the C<attributes> attribute based on the attributes
 captured in the associated meta class.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-MethodAttributes>
+(or L<bug-MooseX-MethodAttributes@rt.cpan.org|mailto:bug-MooseX-MethodAttributes@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#moose.
+
 =head1 AUTHORS
 
 =over 4
@@ -68,9 +90,9 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
